@@ -1,14 +1,12 @@
 package Net::Gandi::Hosting::Disk;
 
 use Moose;
-use Carp;
+use utf8;
 
 extends 'Net::Gandi';
 
 =head1 NAME
 
-=encoding utf-8
-
 Net::Gandi::Hosting::Disk - Interface to manage Disk. 
 
 =head1 DESCRIPTION
@@ -19,7 +17,7 @@ A disk represents a virtual storage device you can attached to a VM. It then beh
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 list 
+=head1 disk_list 
 
 List the disks associated with apikey that match the filter.
 
@@ -71,14 +69,14 @@ sort_by
 
 =cut
 
-sub list {
+sub disk_list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( "disk.list", $params );
 }
 
-=head1 count
+=head1 disk_count
 
 Returns the number of VMs associated with apikey, matched by filters, if specified.
 
@@ -118,14 +116,14 @@ datacenter_id
 
 =cut
 
-sub count {
+sub disk_count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('disk.count', $params);
 }
 
-=head1 info
+=head1 disk_info
 
 Return a mapping of the disk attributes.
 
@@ -133,15 +131,13 @@ Parameter: None
 
 =cut 
 
-sub info {
+sub disk_info {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
     return $self->call_rpc( 'disk.info', $self->id );
 }
 
-=head1 get_options
+=head1 disk_get_options
 
 Returns available kernels and kernel options for this disk.
 
@@ -149,106 +145,60 @@ Parameter: None
 
 =cut 
 
-sub get_options {
+sub disk_get_options {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'disk.get_options', $self->id );
 }
 
-=head1 create
+=head1 disk_create
 
 Create a disk.
 
 =cut
 
-sub create {
+sub disk_create {
     my ( $self, $params ) = @_;
 
     return $self->call_rpc( "disk.create", $params );
 }
 
-=head1 create_from
+=head1 disk_create_from
 
 Create a disk with the same data as the disk identified by src_disk_id.
 
 =cut
 
-sub create_from {
+sub disk_create_from {
     my ( $self, $params, $src_disk_id ) = @_;
 
     return $self->call_rpc( "disk.create", $params, $src_disk_id );
 }
 
-=head1 update
+=head1 disk_update
 
 Update the disk to match the expected attributes.
 
 =cut
 
-sub update {
+sub disk_update {
     my ( $self, $params ) = @_;
 
-
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('disk.update', $self->id, $params);
 }
 
-=head1 delete
+=head1 disk_delete
 
 Delete a disk. Warning, erase data. Free the quota used by the disk size.
 
 =cut
 
-sub delete {
+sub disk_delete {
     my ( $self ) = @_;
 
-
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('disk.delete', $self->id);
 }
 
-=head1 attach
-
-Attach a disk to a VM. 
-The account associated with apikey MUST own both VM and disk.
-A disk can only be attached to one VM.
-
-Params: vm_id
-
-=cut
-
-sub attach {
-    my ( $self, $vm_id, $params ) = @_;
-
-    carp 'Required parameter id is not defined' if ( ! $vm_id );
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
-    if ( $params ) {
-        return $self->call_rpc('vm.disk_attach', $vm_id, $self->id, $params);
-    }
-    else {
-        return $self->call_rpc('vm.disk_attach', $vm_id, $self->id);
-    }
-}
-
-=head1 detach
-
-Detach a disk from a VM. The disk MUST not be mounted on the VM. If the disk position is 0, the VM MUST be halted to detach the disk
-
-Params: vm_id
-
-=cut
-
-sub detach {
-    my ( $self, $vm_id ) = @_;
-
-    carp 'Required parameter id is not defined' if ( ! $vm_id );
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
-    return $self->call_rpc('vm.disk_detach', $vm_id, $self->id);
-}
-
 =head1 AUTHOR
 
 Natal Ngétal, C<< <hobbestig@cpan.org> >>
