@@ -1,13 +1,12 @@
 package Net::Gandi::Hosting::IP;
 
 use Moose;
-use Carp;
+use utf8;
 
 extends 'Net::Gandi';
 
-=head1 NAME
 
-=encoding utf-8
+=head1 NAME
 
 Net::Gandi::Hosting::IP - Interface to manage IP. 
 
@@ -15,33 +14,33 @@ Net::Gandi::Hosting::IP - Interface to manage IP.
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 list
+=head1 ip_list
 
 List IP associated with apikey that match the filter
 
 =cut
 
-sub list {
+sub ip_list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( 'ip.list', $params );
 }
 
-=head1 count 
+=head1 ip_count 
 
 List IP associated with apikey that match the filter
 
 =cut
 
-sub count {
+sub ip_count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('ip.count', $params);
 }
 
-=head1 info
+=head1 ip_info
 
 Return a mapping of the IP attributes.
 
@@ -49,39 +48,36 @@ Parameter: None
 
 =cut 
 
-sub info {
+sub ip_info {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'ip.info', $self->id );
 }
 
-=head1 update
+=head1 ip_update
 
 Updates a IP’s attributes
 
 =cut
 
-sub update {
+sub ip_update {
     my ( $self, $params ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
     $params ||= {};
     return $self->call_rpc('ip.update', $self->id, $params);
 }
 
-#sub attach {
+#sub ip_attach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->call_rpc('iface.attach', $iface_id, $self->id);
+#    return $self->call_rpc('iface.ip_attach', $iface_id, $self->id);
 #}
 
 
-#sub detach {
+#sub ip_detach {
 #    my ( $self, $iface_id ) = @_;
 #
-#    return $self->call_rpc('iface.detach', $iface_id, $self->id);
+#    return $self->call_rpc('iface.ip_detach', $iface_id, $self->id);
 #}
 
 =head1 AUTHOR
