@@ -1,14 +1,12 @@
 package Net::Gandi::Hosting::Iface;
 
 use Moose;
-use Carp;
+use utf8;
 
 extends 'Net::Gandi';
 
 =head1 NAME
 
-=encoding utf-8
-
 Net::Gandi::Hosting::Iface - Interface to manage Iface. 
 
 =head1 DESCRIPTION
@@ -19,7 +17,7 @@ A iface represent a network interface.
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 list 
+=head1 iface_list 
 
 List network interfaces associated to apikey that match the filter.
 
@@ -59,14 +57,14 @@ sort_by
 
 =cut
 
-sub list {
+sub iface_list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( "iface.list", $params );
 }
 
-=head1 count
+=head1 iface_count
 
 Count network interfaces associated to apikey that match the filter
 
@@ -94,61 +92,58 @@ vm_id
 
 =cut
 
-sub count {
+sub iface_count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('iface.count', $params);
 }
 
-=head1 info
+=head1 iface_info
 
 Returns informations about the network interface
 
 =cut 
 
-sub info {
+sub iface_info {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'iface.info', $self->id );
 }
 
-=head1 create
+=head1 iface_create
 
 Create a iface.
 
 =cut
 
-sub create {
+sub iface_create {
     my ( $self, $params ) = @_;
 
     return $self->call_rpc( "iface.create", $params );
 }
 
-=head1 update
+=head1 iface_update
 
 Updates network interface attributes.
 
 =cut
 
-sub update {
+sub iface_update {
     my ( $self, $params ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( "iface.update", $self->id, $params );
 }
 
-=head1 delete
+=head1 iface_delete
 
 Deletes a network interface.
 
 =cut
 
-sub delete {
+sub iface_delete {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('iface.delete', $self->id);
 }
 
