@@ -1,14 +1,12 @@
 package Net::Gandi::Hosting::VM;
 
 use Moose;
-use Carp;
+use utf8;
 
 extends 'Net::Gandi';
 
 =head1 NAME
 
-=encoding utf-8
-
 Net::Gandi::Hosting::VM - Interface to manage VM. 
 
 =head1 DESCRIPTION
@@ -19,7 +17,7 @@ A VM (Virtual Machine) describes a server’s resources and state.
 
 has 'id' => ( is => 'rw', isa => 'Int' );
 
-=head1 list 
+=head1 vm_list 
 
 Returns the list of VMs associated with apikey, matched by filters, if specified.
 
@@ -71,14 +69,14 @@ sort_by
 
 =cut
 
-sub list {
+sub vm_list {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc( "vm.list", $params );
 }
 
-=head1 count
+=head1 vm_count
 
 Returns the number of VMs associated with apikey, matched by filters, if specified.
 
@@ -118,14 +116,14 @@ datacenter_id
 
 =cut
 
-sub count {
+sub vm_count {
     my ( $self, $params ) = @_;
 
     $params ||= {};
     return $self->call_rpc('vm.count', $params);
 }
 
-=head1 info
+=head1 vm_info
 
 Return a mapping of the VM attributes.
 
@@ -134,24 +132,23 @@ Parameter: None
     use Net::Gandi;
 
     my $vm   = Net::Gandi::Hosting::VM->new( apikey => 'myapikey', id => 42 );
-    my $info = $vm->info;
+    my $info = $vm->vm_info;
 
 =cut 
 
-sub info {
+sub vm_info {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc( 'vm.info', $self->id );
 }
 
-=head1 create
+=head1 vm_create
 
 Creates a VM and returns the corresponding operations.
 
 =cut
 
-sub create {
+sub vm_create {
     my ( $self, $params ) = @_;
 
     foreach my $param ( 'hostname', 'password' ) {
@@ -161,57 +158,51 @@ sub create {
     return $self->call_rpc( "vm.create", $params );
 }
 
-=head1 create_from 
+=head1 vm_create_from 
 
 Creates a Disk, and then, a VM, and returns the corresponding operations.
 It combines the API method disk.create, and vm.create.
 This is a convenient method to do the disk.create and vm.create in a single API call.
-Three operations are created and returned (in this order): disk_create, iface_create, create
+Three operations are created and returned (in this order): disk_create, iface_create, vm_create
 
 =cut
 
-sub create_from {
-    my ( $self, $params, $disk_params, $src_disk_id ) = @_;
+sub vm_create_from {
+    my ( $self, $vm_params, $disk_params, $src_disk_id ) = @_;
 
     foreach my $param ( 'hostname', 'password' ) {
-        $params->{$param} = XMLRPC::Data
+        $vm_params->{$param} = XMLRPC::Data
             ->type('string')
-            ->value($params->{$param});
+            ->value($vm_params->{$param});
     }
 
-    return $self->call_rpc( "vm.create_from", $params, $disk_params, $src_disk_id );
+    return $self->call_rpc( "vm.create", $vm_params, $disk_params, $src_disk_id );
 }
 
-=head1 update
+=head1 vm_update
 
 Updates a VM.
 
 =cut
 
-sub update {
+sub vm_update {
     my ( $self, $params ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
     $params ||= {};
     return $self->call_rpc('vm.update', $self->id, $params);
 }
 
-=head1 disk_attach
+=head1 vm_disk_attach
 
 Attach a disk to a VM. 
 The account associated with apikey MUST own both VM and disk.
 A disk can only be attached to one VM.
 
-Params: disk_id
-
 =cut
 
-sub disk_attach {
+sub vm_disk_attach {
     my ( $self, $disk_id, $params ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
     if ( $params ) {
         return $self->call_rpc('vm.disk_attach', $self->id, $disk_id, $params);
     }
@@ -220,7 +211,7 @@ sub disk_attach {
     }
 }
 
-=head1 disk_detach
+=head1 vm_disk_detach
 
 Detach a disk from a VM. The disk MUST not be mounted on the VM. If the disk position is 0, the VM MUST be halted to detach the disk
 
@@ -228,55 +219,48 @@ Params: disk_id
 
 =cut
 
-sub disk_detach {
+sub vm_disk_detach {
     my ( $self, $disk_id ) = @_;
 
-
-    carp 'Required parameter id is not defined' if ( ! $self->id );
-
-    return $self->call_rpc('vm.disk_detach', $self->id, $disk_id);
+    return $self->call_rpc('vm.disk_attach', $self->id, $disk_id);
 }
 
-
-=head1 start
+=head1 vm_start
 
 Starts a VM and return the corresponding operation
 Parameter: None
 
 =cut
 
-sub start {
+sub vm_start {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('vm.start', $self->id);
 }
 
-=head1 stop
+=head1 vm_stop
 
 Stops a VM and returns the corresponding operation.
 Parameter: None
 
 =cut
 
-sub stop {
+sub vm_stop {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('vm.stop', $self->id);
 }
 
-=head1 reboot
+=head1 vm_reboot
 
 Reboots a VM and returns the corresponding operation
 Parameter: None
 
 =cut
 
-sub reboot {
+sub vm_reboot {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('vm.reboot', $self->id);
 }
 
@@ -288,10 +272,9 @@ Parameter: None
 
 =cut
 
-sub delete {
+sub vm_delete {
     my ( $self ) = @_;
 
-    carp 'Required parameter id is not defined' if ( ! $self->id );
     return $self->call_rpc('vm.delete', $self->id);
 }
 
